**this file will be overwriten! **

 - Write documentation describing your app, files starting __ are ignored.

 - or add to `links.json`

## Settings

 - *activation*: <i>sequencer</i>

 - *run_state*: None

 - *progress*: None

 - *profile*: Run a profile on the run to find performance problems

 - *cycles*: number of times the sequence is executed

 - *paused*: None

 - *recipe_folder*: None

 - *sequence_file*: None

